@@ -110,7 +110,7 @@ from dagster.core.instance import DagsterInstance
 from dagster.core.launcher import DefaultRunLauncher
 from dagster.core.log_manager import DagsterLogManager
 from dagster.core.storage.file_manager import FileHandle, LocalFileHandle, local_file_manager
-from dagster.core.storage.init import InitSystemStorageContext
+from dagster.core.storage.init import InitIntermediateStorageContext, InitSystemStorageContext
 from dagster.core.storage.pipeline_run import PipelineRun
 from dagster.core.storage.system_storage import (
     build_intermediate_storage_from_object_store,
@@ -127,7 +127,13 @@ from dagster.core.types.config_schema import (
     input_hydration_config,
     output_materialization_config,
 )
-from dagster.core.types.dagster_type import DagsterType, List, Optional, PythonObjectDagsterType
+from dagster.core.types.dagster_type import (
+    DagsterType,
+    List,
+    Optional,
+    PythonObjectDagsterType,
+    PythonUnionDagsterType,
+)
 from dagster.core.types.decorator import (
     make_python_type_usable_as_dagster_type,
     usable_as_dagster_type,
@@ -207,6 +213,7 @@ __all__ = [
     'InitLoggerContext',
     'InitResourceContext',
     'InitSystemStorageContext',
+    'InitIntermediateStorageContext',
     'PipelineExecutionResult',
     'RetryRequested',
     'SolidExecutionResult',
@@ -282,6 +289,7 @@ __all__ = [
     # type creation
     'DagsterType',
     'PythonObjectDagsterType',
+    'PythonUnionDagsterType',
     'make_python_type_usable_as_dagster_type',
     'usable_as_dagster_type',
     # config
