@@ -6,6 +6,7 @@ import click
 from ..core.instance import DagsterInstance
 from ..version import __version__
 from .api import api_cli
+from .asset import asset_cli
 from .instance import instance_cli
 from .pipeline import pipeline_cli
 from .run import run_cli
@@ -19,6 +20,7 @@ def create_dagster_cli():
         'run': run_cli,
         'instance': instance_cli,
         'schedule': schedule_cli,
+        'asset': asset_cli,
     }
 
     @click.group(commands=commands)
@@ -26,8 +28,6 @@ def create_dagster_cli():
     def group():
         'CLI tools for working with dagster.'
 
-    # add the path for the cwd so imports in dynamically loaded code work correctly
-    sys.path.append(os.getcwd())
     return group
 
 
