@@ -15,6 +15,7 @@ from .dependency import (
     SolidHandle,
     SolidInvocation,
 )
+from .hook import HookDefinition
 from .mode import ModeDefinition
 from .preset import PresetDefinition
 from .solid import ISolidDefinition
@@ -203,7 +204,9 @@ class PipelineDefinition(IContainSolids):
             self._preset_dict[preset.name] = preset
 
         # Validate solid resource dependencies
-        _validate_resource_dependencies(self._mode_definitions, self._current_level_solid_defs)
+        _validate_resource_dependencies(
+            self._mode_definitions, self._current_level_solid_defs, self._solid_dict
+        )
 
         # Validate unsatisfied inputs can be materialized from config
         _validate_inputs(self._dependency_structure, self._solid_dict)
@@ -432,17 +435,11 @@ class PipelineDefinition(IContainSolids):
         return self.get_pipeline_index().pipeline_snapshot_id
 
     def get_pipeline_index(self):
-        from dagster.core.snap import (
-            PipelineSnapshot,
-            PipelineSnapshotWithID,
-        )
+        from dagster.core.snap import PipelineSnapshot
         from dagster.core.host_representation import PipelineIndex
 
         return PipelineIndex(
-            PipelineSnapshotWithID.from_snapshot(PipelineSnapshot.from_pipeline_def(self)),
-            PipelineSnapshotWithID.from_snapshot(self.get_parent_pipeline_snapshot())
-            if self.parent_pipeline_def
-            else None,
+            PipelineSnapshot.from_pipeline_def(self), self.get_parent_pipeline_snapshot()
         )
 
     def get_config_schema_snapshot(self):
@@ -463,6 +460,37 @@ class PipelineDefinition(IContainSolids):
     def solids_to_execute(self):
         return None
 
+    def with_hooks(self, hook_defs):
+        '''Apply a set of hooks to all solid instances within the pipeline.'''
+
+        hook_defs = check.set_param(hook_defs, 'hook_defs', of_type=HookDefinition)
+
+        # make a copy of the pipeline definition with the hook added to every solid instance
+        deps = {}
+        for dep_key, input_dep_dict in self.dependencies.items():
+            check.inst(dep_key, six.string_types + (SolidInvocation,))
+            # to add hooks, we make copies of solid invocations
+            hooked_invocation = (
+                SolidInvocation(
+                    dep_key.name, dep_key.alias, dep_key.tags, dep_key.hook_defs.union(hook_defs),
+                )
+                if isinstance(dep_key, SolidInvocation)
+                else SolidInvocation(dep_key, hook_defs=hook_defs)  # when dep_key is str
+            )
+
+            deps[hooked_invocation] = input_dep_dict
+
+        return PipelineDefinition(
+            solid_defs=self.all_solid_defs,
+            name=self.name,
+            description=self.description,
+            dependencies=deps,
+            mode_defs=self.mode_definitions,
+            preset_defs=self.preset_defs,
+            tags=self.tags,
+            _parent_pipeline_def=self._parent_pipeline_def,
+        )
+
 
 class PipelineSubsetDefinition(PipelineDefinition):
     @property
@@ -483,9 +511,6 @@ class PipelineSubsetDefinition(PipelineDefinition):
     def get_parent_pipeline_snapshot(self):
         return self._parent_pipeline_def.get_pipeline_snapshot()
 
-    def get_parent_pipeline_snapshot_id(self):
-        return self._parent_pipeline_def.get_pipeline_snapshot_id()
-
     @property
     def is_subset_pipeline(self):
         return True
@@ -545,12 +570,13 @@ def _get_pipeline_subset_def(pipeline_def, solids_to_execute):
             mode_defs=pipeline_def.mode_definitions,
             dependencies=deps,
             _parent_pipeline_def=pipeline_def,
+            tags=pipeline_def.tags,
         )
 
         return sub_pipeline_def
     except DagsterInvalidDefinitionError as exc:
         # This handles the case when you construct a subset such that an unsatisfied
-        # input cannot be hydrate from config. Instead of throwing a DagsterInvalidDefinitionError,
+        # input cannot be loaded from config. Instead of throwing a DagsterInvalidDefinitionError,
         # we re-raise a DagsterInvalidSubsetError.
         six.raise_from(
             DagsterInvalidSubsetError(
@@ -563,7 +589,7 @@ def _get_pipeline_subset_def(pipeline_def, solids_to_execute):
         )
 
 
-def _validate_resource_dependencies(mode_definitions, solid_defs):
+def _validate_resource_dependencies(mode_definitions, solid_defs, solid_dict):
     '''This validation ensures that each pipeline context provides the resources that are required
     by each solid.
     '''
@@ -598,6 +624,20 @@ def _validate_resource_dependencies(mode_definitions, solid_defs):
                             mode_name=mode_def.name,
                         )
                     )
+        for solid in solid_dict.values():
+            for hook_def in solid.hook_defs:
+                for required_resource in hook_def.required_resource_keys:
+                    if required_resource not in mode_resources:
+                        raise DagsterInvalidDefinitionError(
+                            (
+                                'Resource "{resource}" is required by hook "{hook_name}", but is not '
+                                'provided by mode "{mode_name}".'
+                            ).format(
+                                resource=required_resource,
+                                hook_name=hook_def.name,
+                                mode_name=mode_def.name,
+                            )
+                        )
 
 
 def _validate_inputs(dependency_structure, solid_dict):
@@ -605,15 +645,15 @@ def _validate_inputs(dependency_structure, solid_dict):
         for handle in solid.input_handles():
             if not dependency_structure.has_deps(handle):
                 if (
-                    not handle.input_def.dagster_type.input_hydration_config
+                    not handle.input_def.dagster_type.loader
                     and not handle.input_def.dagster_type.kind == DagsterTypeKind.NOTHING
                 ):
                     raise DagsterInvalidDefinitionError(
                         'Input "{input_name}" in solid "{solid_name}" is not connected to '
-                        'the output of a previous solid and can not be hydrated from configuration, '
+                        'the output of a previous solid and can not be loaded from configuration, '
                         'creating an impossible to execute pipeline. '
                         'Possible solutions are:\n'
-                        '  * add a input_hydration_config for the type "{dagster_type}"\n'
+                        '  * add a dagster_type_loader for the type "{dagster_type}"\n'
                         '  * connect "{input_name}" to the output of another solid\n'.format(
                             solid_name=solid.name,
                             input_name=handle.input_def.name,
