@@ -12,11 +12,10 @@ from dagster.core.definitions.reconstructable import (
 from dagster.core.definitions.step_launcher import StepLauncher, StepRunRef
 from dagster.core.execution.api import create_execution_plan
 from dagster.core.execution.context.system import SystemStepExecutionContext
-from dagster.core.execution.context_creation_pipeline import pipeline_initialization_manager
+from dagster.core.execution.context_creation_pipeline import PlanExecutionContextManager
 from dagster.core.execution.plan.execute_step import core_dagster_event_sequence_for_step
-from dagster.core.execution.retries import Retries
 from dagster.core.instance import DagsterInstance
-from dagster.core.storage.file_manager import LocalFileHandle
+from dagster.core.storage.file_manager import LocalFileHandle, LocalFileManager
 
 PICKLED_EVENTS_FILE_NAME = 'events.pkl'
 PICKLED_STEP_RUN_REF_FILE_NAME = 'step_run_ref.pkl'
@@ -52,7 +51,7 @@ class LocalExternalStepLauncher(StepLauncher):
             pickle.dump(step_run_ref, step_pickle_file)
 
         command_tokens = [
-            'python',
+            sys.executable,
             '-m',
             'dagster.core.execution.plan.local_external_step_main',
             step_run_ref_file_path,
@@ -60,8 +59,9 @@ class LocalExternalStepLauncher(StepLauncher):
         subprocess.call(command_tokens, stdout=sys.stdout, stderr=sys.stderr)
 
         events_file_path = os.path.join(step_run_dir, PICKLED_EVENTS_FILE_NAME)
+        file_manager = LocalFileManager('.')
         events_file_handle = LocalFileHandle(events_file_path)
-        events_data = step_context.file_manager.read_data(events_file_handle)
+        events_data = file_manager.read_data(events_file_handle)
         events = pickle.loads(events_data)
 
         for event in events:
@@ -100,34 +100,9 @@ def step_context_to_step_run_ref(step_context, prior_attempts_count, package_dir
     '''
 
     check.inst_param(step_context, 'step_context', SystemStepExecutionContext)
-
-    # This is a bit goofy right now, as the relationship between
-    # step launcher and the executor is a little weird.
-    #
-    # As far as I can tell, the only goal of interacting with the executor here
-    # is for the step launcher to inherit the retry policy. The step launcher
-    # actually assumes that a retry policy exists (hence the invariants below).
-    # However this isn't a formal requirement, so this can break. E.g. right
-    # now using a dask executor and the step launcher would fail.
-    #
-    # Once migration is complete, I think we should add a retries property
-    # to the Executor abc and make it optional. Then change this to handle
-    # the "no retry" case
-    check.param_invariant(
-        hasattr(step_context.executor, 'retries'),
-        'step_context',
-        'Executor must have retries property',
-    )
-    check.param_invariant(
-        isinstance(step_context.executor.retries, Retries),
-        'step_context',
-        'Executor retries property must be of type Retries. Object was {}'.format(
-            step_context.executor
-        ),
-    )
     check.int_param(prior_attempts_count, 'prior_attempts_count')
 
-    retries = step_context.executor.retries
+    retries = step_context.retries
 
     recon_pipeline = step_context.pipeline
     if package_dir:
@@ -166,23 +141,23 @@ def step_run_ref_to_step_context(step_run_ref):
     execution_plan = create_execution_plan(
         pipeline, step_run_ref.run_config, mode=step_run_ref.pipeline_run.mode
     ).build_subset_plan([step_run_ref.step_key])
+    retries = step_run_ref.retries.for_inner_plan()
 
-    initialization_manager = pipeline_initialization_manager(
+    initialization_manager = PlanExecutionContextManager(
+        retries,
         execution_plan,
         step_run_ref.run_config,
         step_run_ref.pipeline_run,
         DagsterInstance.ephemeral(),
     )
-    for _ in initialization_manager.generate_setup_events():
+    for _ in initialization_manager.prepare_context():
         pass
-    pipeline_context = initialization_manager.get_object()
+    execution_context = initialization_manager.get_context()
 
-    retries = step_run_ref.retries.for_inner_plan()
     active_execution = execution_plan.start(retries=retries)
     step = active_execution.get_next_step()
 
-    pipeline_context = initialization_manager.get_object()
-    return pipeline_context.for_step(step)
+    return execution_context.for_step(step)
 
 
 def run_step_from_ref(step_run_ref):
