@@ -58,6 +58,12 @@ def _dagster_home():
         raise DagsterInvariantViolationError(
             'DAGSTER_HOME must be absolute path: {}'.format(dagster_home_path)
         )
+
+    if not (os.path.exists(dagster_home_path) and os.path.isdir(dagster_home_path)):
+        raise DagsterInvariantViolationError(
+            'DAGSTER_HOME "{}" is not a folder or does not exist!'.format(dagster_home_path)
+        )
+
     return dagster_home_path
 
 
@@ -127,9 +133,11 @@ class InstanceType(Enum):
 class DagsterInstance:
     '''Core abstraction for managing Dagster's access to storage and other resources.
 
-    Users should not directly instantiate this class; it is instantiated by internal machinery when
-    ``dagit`` and ``dagster-graphql`` load, based on the values in the ``dagster.yaml`` file in
-    ``$DAGSTER_HOME``. Configuration of this class should be done by setting values in that file.
+    Use DagsterInstance.get() to grab the current DagsterInstance which will load based on
+    the values in the ``dagster.yaml`` file in ``$DAGSTER_HOME`` if set, otherwise fallback
+    to using an ephemeral in-memory set of components.
+
+    Configuration of this class should be done by setting values in ``$DAGSTER_HOME/dagster.yaml``.
     For example, to use Postgres for run and event log storage, you can write a ``dagster.yaml``
     such as the following:
 
@@ -162,11 +170,9 @@ class DagsterInstance:
         run_launcher (Optional[RunLauncher]): Optionally, a run launcher may be used to enable
             a Dagster instance to launch pipeline runs, e.g. on a remote Kubernetes cluster, in
             addition to running them locally.
-        dagit_settings (Optional[Dict]): Specifies certain Dagit-specific, per-instance settings,
-            such as feature flags. These are set in the ``dagster.yaml`` under the key ``dagit``.
-        telemetry_settings (Optional[Dict]): Specifies certain telemetry-specific, per-instance
-            settings, such as whether it is enabled. These are set in the ``dagster.yaml`` under
-            the key ``telemetry``
+        settings (Optional[Dict]): Specifies certain per-instance settings,
+            such as feature flags. These are set in the ``dagster.yaml`` under a set of whitelisted
+            keys.
         ref (Optional[InstanceRef]): Used by internal machinery to pass instances across process
             boundaries.
     '''
@@ -183,8 +189,7 @@ class DagsterInstance:
         schedule_storage=None,
         scheduler=None,
         run_launcher=None,
-        dagit_settings=None,
-        telemetry_settings=None,
+        settings=None,
         ref=None,
     ):
         from dagster.core.storage.compute_log_manager import ComputeLogManager
@@ -209,8 +214,9 @@ class DagsterInstance:
         )
         self._scheduler = check.opt_inst_param(scheduler, 'scheduler', Scheduler)
         self._run_launcher = check.inst_param(run_launcher, 'run_launcher', RunLauncher)
-        self._dagit_settings = check.opt_dict_param(dagit_settings, 'dagit_settings')
-        self._telemetry_settings = check.opt_dict_param(telemetry_settings, 'telemetry_settings')
+        self._run_launcher.initialize(self)
+
+        self._settings = check.opt_dict_param(settings, 'settings')
 
         self._ref = check.opt_inst_param(ref, 'ref', InstanceRef)
 
@@ -278,8 +284,7 @@ class DagsterInstance:
             schedule_storage=instance_ref.schedule_storage,
             scheduler=instance_ref.scheduler,
             run_launcher=instance_ref.run_launcher,
-            dagit_settings=instance_ref.dagit_settings,
-            telemetry_settings=instance_ref.telemetry_settings,
+            settings=instance_ref.settings,
             ref=instance_ref,
         )
 
@@ -328,20 +333,16 @@ class DagsterInstance:
 
     def info_str(self):
 
-        dagit_settings = self._dagit_settings if self._dagit_settings else None
-        telemetry_settings = self._telemetry_settings if self._telemetry_settings else None
+        settings = self._settings if self._settings else None
 
         return (
-            'DagsterInstance components:\n\n'
-            '  Local Artifacts Storage:\n{artifact}\n'
-            '  Run Storage:\n{run}\n'
-            '  Event Log Storage:\n{event}\n'
-            '  Compute Log Manager:\n{compute}\n'
-            '  Schedule Storage:\n{schedule_storage}\n'
-            '  Scheduler:\n{scheduler}\n'
-            '  Run Launcher:\n{run_launcher}\n'
-            '  Dagit:\n{dagit}\n'
-            '  Telemetry:\n{telemetry}\n'
+            'local_artifact_storage:\n{artifact}\n'
+            'run_storage:\n{run}\n'
+            'event_log_storage:\n{event}\n'
+            'compute_logs:\n{compute}\n'
+            'schedule_storage:\n{schedule_storage}\n'
+            'scheduler:\n{scheduler}\n'
+            'run_launcher:\n{run_launcher}\n'
             ''.format(
                 artifact=self._info(self._local_artifact_storage),
                 run=self._info(self._run_storage),
@@ -350,8 +351,14 @@ class DagsterInstance:
                 schedule_storage=self._info(self._schedule_storage),
                 scheduler=self._info(self._scheduler),
                 run_launcher=self._info(self._run_launcher),
-                dagit=self._info(dagit_settings),
-                telemetry=self._info(telemetry_settings),
+            )
+            + '\n'.join(
+                [
+                    '{settings_key}:\n{settings_value}'.format(
+                        settings_key=settings_key, settings_value=self._info(settings_value)
+                    )
+                    for settings_key, settings_value in settings.items()
+                ]
             )
         )
 
@@ -379,10 +386,10 @@ class DagsterInstance:
     def compute_log_manager(self):
         return self._compute_log_manager
 
-    @property
-    def dagit_settings(self):
-        if self._dagit_settings:
-            return self._dagit_settings
+    def get_settings(self, settings_key):
+        check.str_param(settings_key, 'settings_key')
+        if self._settings and settings_key in self._settings:
+            return self._settings.get(settings_key)
         return {}
 
     @property
@@ -392,11 +399,13 @@ class DagsterInstance:
 
         dagster_telemetry_enabled_default = True
 
-        if not self._telemetry_settings:
+        telemetry_settings = self.get_settings('telemetry')
+
+        if not telemetry_settings:
             return dagster_telemetry_enabled_default
 
-        if 'enabled' in self._telemetry_settings:
-            return self._telemetry_settings['enabled']
+        if 'enabled' in telemetry_settings:
+            return telemetry_settings['enabled']
         else:
             return dagster_telemetry_enabled_default
 
@@ -919,6 +928,11 @@ class DagsterInstance:
         check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
         message = "This pipeline run has been marked as failed from outside the execution context"
 
+        dagster_event = DagsterEvent(
+            event_type_value=DagsterEventType.PIPELINE_FAILURE.value,
+            pipeline_name=pipeline_run.pipeline_name,
+            message=message,
+        )
         event_record = DagsterEventRecord(
             message=message,
             user_message=message,
@@ -927,13 +941,10 @@ class DagsterInstance:
             run_id=pipeline_run.run_id,
             error_info=None,
             timestamp=time.time(),
-            dagster_event=DagsterEvent(
-                event_type_value=DagsterEventType.PIPELINE_FAILURE.value,
-                pipeline_name=pipeline_run.pipeline_name,
-                message=message,
-            ),
+            dagster_event=dagster_event,
         )
         self.handle_new_event(event_record)
+        return dagster_event
 
     # directories
 
@@ -1015,7 +1026,8 @@ class DagsterInstance:
                     "status": schedule_state.status.value,
                     "cron_schedule": schedule_state.cron_schedule,
                     "python_path": schedule_state.pipeline_origin.executable_path,
-                    "repository_pointer": schedule_state.pipeline_origin.get_repo_pointer().describe(),
+                    "pipeline_origin_id": schedule_state.pipeline_origin.get_id(),
+                    "repository_pointer": schedule_state.pipeline_origin.get_repo_cli_args(),
                     "schedule_origin_id": schedule_state.schedule_origin_id,
                     "repository_origin_id": schedule_state.repository_origin_id,
                 }
