@@ -8,7 +8,7 @@ from dagster import check
 from dagster.core.errors import DagsterError
 from dagster.core.host_representation import ExternalSchedule
 from dagster.core.instance import DagsterInstance
-from dagster.core.origin import SchedulePythonOrigin
+from dagster.core.origin import ScheduleOrigin
 from dagster.serdes import whitelist_for_serdes
 from dagster.utils.error import SerializableErrorInfo
 
@@ -120,7 +120,7 @@ class ScheduleState(namedtuple('_StoredScheduleState', 'origin status cron_sched
         return super(ScheduleState, cls).__new__(
             cls,
             # Using the term "origin" to leave flexibility in handling future types
-            check.inst_param(origin, 'origin', SchedulePythonOrigin),
+            check.inst_param(origin, 'origin', ScheduleOrigin),
             check.inst_param(status, 'status', ScheduleStatus),
             check.str_param(cron_schedule, 'cron_schedule'),
         )
@@ -132,7 +132,7 @@ class ScheduleState(namedtuple('_StoredScheduleState', 'origin status cron_sched
     @property
     def pipeline_origin(self):
         # Set up for future proofing
-        check.invariant(isinstance(self.origin, SchedulePythonOrigin))
+        check.invariant(isinstance(self.origin, ScheduleOrigin))
         return self.origin
 
     @property
@@ -331,7 +331,7 @@ class Scheduler(six.with_metaclass(abc.ABCMeta)):
         for the given schedule.
 
         Args:
-            instance (DagsterInstance): The current instance.S
+            instance (DagsterInstance): The current instance.
             external_schedule (ExternalSchedule): The schedule to start running.
         '''
 
@@ -415,12 +415,8 @@ def _validate_schedule_tick_args(status, run_id=None, error=None):
             error is None, desc="Schedule tick status is SUCCESS, but error was provided"
         )
     elif status == ScheduleTickStatus.FAILURE:
-        check.invariant(run_id is None, "Schedule tick status is FAILURE but run_id was provided")
         check.inst_param(error, 'error', SerializableErrorInfo)
     else:
-        check.invariant(
-            run_id is None, "Schedule tick status was not SUCCESS, but run_id was provided"
-        )
         check.invariant(
             error is None, "Schedule tick status was not FAILURE but error was provided"
         )
@@ -457,8 +453,7 @@ class ScheduleTickData(
             status (ScheduleTickStatus): The status of the tick, which can be updated
 
         Keyword Arguments:
-            run_id (str): The run created by the tick. This is set only when the status is
-                ``ScheduleTickStatus.SUCCESS``
+            run_id (str): The run created by the tick.
             error (SerializableErrorInfo): The error caught during schedule execution. This is set
                 only when the status is ``ScheduleTickStatus.Failure``
         '''
