@@ -12,9 +12,10 @@ from dagster.core.definitions.events import TypeCheck
 from dagster.core.errors import DagsterInvalidDefinitionError, DagsterInvariantViolationError
 from dagster.core.storage.type_storage import TypeStoragePlugin
 from dagster.serdes import whitelist_for_serdes
+from dagster.utils.backcompat import canonicalize_backcompat_args, rename_warning
 
 from .builtin_config_schemas import BuiltinSchemas
-from .config_schema import InputHydrationConfig, OutputMaterializationConfig
+from .config_schema import DagsterTypeLoader, DagsterTypeMaterializer
 from .marshal import PickleSerializationStrategy, SerializationStrategy
 
 
@@ -53,16 +54,16 @@ class DagsterType(object):
             becomes this value. Name is not given in a case where the user does
             not specify a unique name for this type, such as a generic class.
         description (Optional[str]): A markdown-formatted string, displayed in tooling.
-        input_hydration_config (Optional[InputHydrationConfig]): An instance of a class that
-            inherits from :py:class:`~dagster.InputHydrationConfig` and can map config data to a value of
+        loader (Optional[DagsterTypeLoader]): An instance of a class that
+            inherits from :py:class:`~dagster.DagsterTypeLoader` and can map config data to a value of
             this type. Specify this argument if you will need to shim values of this type using the
             config machinery. As a rule, you should use the
-            :py:func:`@input_hydration_config <dagster.input_hydration_config>` decorator to construct
+            :py:func:`@dagster_type_loader <dagster.dagster_type_loader>` decorator to construct
             these arguments.
-        output_materialization_config (Optional[OutputMaterializationConfig]): An instance of a class
-            that inherits from :py:class:`~dagster.OutputMaterializationConfig` and can persist values of
+        materializer (Optional[DagsterTypeMaterializer]): An instance of a class
+            that inherits from :py:class:`~dagster.DagsterTypeMaterializer` and can persist values of
             this type. As a rule, you should use the
-            :py:func:`@output_materialization_config <dagster.output_materialization_config>`
+            :py:func:`@dagster_type_materializer <dagster.dagster_type_materializer>`
             decorator to construct these arguments.
         serialization_strategy (Optional[SerializationStrategy]): An instance of a class that
             inherits from :py:class:`~dagster.SerializationStrategy`. The default strategy for serializing
@@ -89,12 +90,15 @@ class DagsterType(object):
         name=None,
         is_builtin=False,
         description=None,
-        input_hydration_config=None,
-        output_materialization_config=None,
+        loader=None,
+        materializer=None,
         serialization_strategy=None,
         auto_plugins=None,
         required_resource_keys=None,
         kind=DagsterTypeKind.REGULAR,
+        # Graveyard is below
+        input_hydration_config=None,
+        output_materialization_config=None,
     ):
         check.opt_str_param(key, 'key')
         check.opt_str_param(name, 'name')
@@ -116,13 +120,25 @@ class DagsterType(object):
             self.key, self.name = key, name
 
         self.description = check.opt_str_param(description, 'description')
-        self.input_hydration_config = check.opt_inst_param(
-            input_hydration_config, 'input_hydration_config', InputHydrationConfig
+        self.loader = canonicalize_backcompat_args(
+            check.opt_inst_param(loader, 'loader', DagsterTypeLoader),
+            'loader',
+            check.opt_inst_param(
+                input_hydration_config, 'input_hydration_config', DagsterTypeLoader
+            ),
+            'input_hydration_config',
+            '0.10.0',
         )
-        self.output_materialization_config = check.opt_inst_param(
-            output_materialization_config,
+        self.materializer = canonicalize_backcompat_args(
+            check.opt_inst_param(materializer, 'materializer', DagsterTypeMaterializer),
+            'materializer',
+            check.opt_inst_param(
+                output_materialization_config,
+                'output_materialization_config',
+                DagsterTypeMaterializer,
+            ),
             'output_materialization_config',
-            OutputMaterializationConfig,
+            '0.10.0',
         )
         self.serialization_strategy = check.opt_inst_param(
             serialization_strategy,
@@ -189,17 +205,33 @@ class DagsterType(object):
     def inner_types(self):
         return []
 
+    @property
+    def input_hydration_config(self):
+        rename_warning('loader', 'input_hydration_config', '0.10.0')
+        return self.loader
+
+    @property
+    def output_materialization_config(self):
+        rename_warning('materializer', 'output_materialization_config', '0.10.0')
+        return self.materializer
+
     @property
     def input_hydration_schema_key(self):
-        return self.input_hydration_config.schema_type.key if self.input_hydration_config else None
+        rename_warning('loader_schema_key', 'input_hydration_schema_key', '0.10.0')
+        return self.loader_schema_key
+
+    @property
+    def loader_schema_key(self):
+        return self.loader.schema_type.key if self.loader else None
 
     @property
     def output_materialization_schema_key(self):
-        return (
-            self.output_materialization_config.schema_type.key
-            if self.output_materialization_config
-            else None
-        )
+        rename_warning('materializer_schema_key', 'output_materialization_schema_key', '0.10.0')
+        return self.materializer_schema_key
+
+    @property
+    def materializer_schema_key(self):
+        return self.materializer.schema_type.key if self.materializer else None
 
     @property
     def type_param_keys(self):
@@ -263,8 +295,8 @@ class _Int(BuiltinScalarDagsterType):
     def __init__(self):
         super(_Int, self).__init__(
             name='Int',
-            input_hydration_config=BuiltinSchemas.INT_INPUT,
-            output_materialization_config=BuiltinSchemas.INT_OUTPUT,
+            loader=BuiltinSchemas.INT_INPUT,
+            materializer=BuiltinSchemas.INT_OUTPUT,
             type_check_fn=self.type_check_fn,
         )
 
@@ -290,8 +322,8 @@ class _String(BuiltinScalarDagsterType):
     def __init__(self):
         super(_String, self).__init__(
             name='String',
-            input_hydration_config=BuiltinSchemas.STRING_INPUT,
-            output_materialization_config=BuiltinSchemas.STRING_OUTPUT,
+            loader=BuiltinSchemas.STRING_INPUT,
+            materializer=BuiltinSchemas.STRING_OUTPUT,
             type_check_fn=self.type_check_fn,
         )
 
@@ -303,8 +335,8 @@ class _Float(BuiltinScalarDagsterType):
     def __init__(self):
         super(_Float, self).__init__(
             name='Float',
-            input_hydration_config=BuiltinSchemas.FLOAT_INPUT,
-            output_materialization_config=BuiltinSchemas.FLOAT_OUTPUT,
+            loader=BuiltinSchemas.FLOAT_INPUT,
+            materializer=BuiltinSchemas.FLOAT_OUTPUT,
             type_check_fn=self.type_check_fn,
         )
 
@@ -316,8 +348,8 @@ class _Bool(BuiltinScalarDagsterType):
     def __init__(self):
         super(_Bool, self).__init__(
             name='Bool',
-            input_hydration_config=BuiltinSchemas.BOOL_INPUT,
-            output_materialization_config=BuiltinSchemas.BOOL_OUTPUT,
+            loader=BuiltinSchemas.BOOL_INPUT,
+            materializer=BuiltinSchemas.BOOL_OUTPUT,
             type_check_fn=self.type_check_fn,
         )
 
@@ -330,8 +362,8 @@ class Anyish(DagsterType):
         self,
         key,
         name,
-        input_hydration_config=None,
-        output_materialization_config=None,
+        loader=None,
+        materializer=None,
         serialization_strategy=None,
         is_builtin=False,
         description=None,
@@ -341,8 +373,8 @@ class Anyish(DagsterType):
             key=key,
             name=name,
             kind=DagsterTypeKind.ANY,
-            input_hydration_config=input_hydration_config,
-            output_materialization_config=output_materialization_config,
+            loader=loader,
+            materializer=materializer,
             serialization_strategy=serialization_strategy,
             is_builtin=is_builtin,
             type_check_fn=self.type_check_method,
@@ -359,16 +391,16 @@ class _Any(Anyish):
         super(_Any, self).__init__(
             key='Any',
             name='Any',
-            input_hydration_config=BuiltinSchemas.ANY_INPUT,
-            output_materialization_config=BuiltinSchemas.ANY_OUTPUT,
+            loader=BuiltinSchemas.ANY_INPUT,
+            materializer=BuiltinSchemas.ANY_OUTPUT,
             is_builtin=True,
         )
 
 
 def create_any_type(
     name,
-    input_hydration_config=None,
-    output_materialization_config=None,
+    loader=None,
+    materializer=None,
     serialization_strategy=None,
     description=None,
     auto_plugins=None,
@@ -377,8 +409,8 @@ def create_any_type(
         key=name,
         name=name,
         description=description,
-        input_hydration_config=input_hydration_config,
-        output_materialization_config=output_materialization_config,
+        loader=loader,
+        materializer=materializer,
         serialization_strategy=serialization_strategy,
         auto_plugins=auto_plugins,
     )
@@ -390,8 +422,8 @@ class _Nothing(DagsterType):
             key='Nothing',
             name='Nothing',
             kind=DagsterTypeKind.NOTHING,
-            input_hydration_config=None,
-            output_materialization_config=None,
+            loader=None,
+            materializer=None,
             type_check_fn=self.type_check_method,
             is_builtin=True,
         )
@@ -415,16 +447,16 @@ class PythonObjectDagsterType(DagsterType):
         name (Optional[str]): Name the type. Defaults to the name of ``python_type``.
         key (Optional[str]): Key of the type. Defaults to name.
         description (Optional[str]): A markdown-formatted string, displayed in tooling.
-        input_hydration_config (Optional[InputHydrationConfig]): An instance of a class that
-            inherits from :py:class:`~dagster.InputHydrationConfig` and can map config data to a value of
+        loader (Optional[DagsterTypeLoader]): An instance of a class that
+            inherits from :py:class:`~dagster.DagsterTypeLoader` and can map config data to a value of
             this type. Specify this argument if you will need to shim values of this type using the
             config machinery. As a rule, you should use the
-            :py:func:`@input_hydration_config <dagster.InputHydrationConfig>` decorator to construct
+            :py:func:`@dagster_type_loader <dagster.dagster_type_loader>` decorator to construct
             these arguments.
-        output_materialization_config (Optional[OutputMaterializationConfig]): An instance of a class
-            that inherits from :py:class:`~dagster.OutputMaterializationConfig` and can persist values of
+        materializer (Optional[DagsterTypeMaterializer]): An instance of a class
+            that inherits from :py:class:`~dagster.DagsterTypeMaterializer` and can persist values of
             this type. As a rule, you should use the
-            :py:func:`@output_materialization_config <dagster.output_materialization_config>`
+            :py:func:`@dagster_type_mate <dagster.dagster_type_mate>`
             decorator to construct these arguments.
         serialization_strategy (Optional[SerializationStrategy]): An instance of a class that
             inherits from :py:class:`SerializationStrategy`. The default strategy for serializing
@@ -464,13 +496,81 @@ class PythonObjectDagsterType(DagsterType):
         return TypeCheck(success=True)
 
 
-class NoneableInputSchema(InputHydrationConfig):
+class PythonUnionDagsterType(DagsterType):
+    '''Define a type in dagster whose typecheck is an isinstance check over a union defined as a tuple of types.
+
+    Args:
+        python_types (Tuple[Type]): The dagster typecheck function calls instanceof on
+            this type tuple.
+        name (Optional[str]): Name the type. Defaults to "Union[```(type.__name__ for type in python_types)```]".
+        key (Optional[str]): Key of the type. Defaults to name.
+        description (Optional[str]): A markdown-formatted string, displayed in tooling.
+        loader (Optional[DagsterTypeLoader]): An instance of a class that
+            inherits from :py:class:`~dagster.DagsterTypeLoader` and can map config data to a value of
+            this type. Specify this argument if you will need to shim values of this type using the
+            config machinery. As a rule, you should use the
+            :py:func:`@dagster_type_loader <dagster.dagster_type_loader>` decorator to construct
+            these arguments.
+        materializer (Optional[DagsterTypeMaterializer]): An instance of a class
+            that inherits from :py:class:`~dagster.DagsterTypeMaterializer` and can persist values of
+            this type. As a rule, you should use the
+            :py:func:`@dagster_type_mate <dagster.dagster_type_mate>`
+            decorator to construct these arguments.
+        serialization_strategy (Optional[SerializationStrategy]): An instance of a class that
+            inherits from :py:class:`SerializationStrategy`. The default strategy for serializing
+            this value when automatically persisting it between execution steps. You should set
+            this value if the ordinary serialization machinery (e.g., pickle) will not be adequate
+            for this type.
+        auto_plugins (Optional[List[Type[TypeStoragePlugin]]]): If types must be serialized differently
+            depending on the storage being used for intermediates, they should specify this
+            argument. In these cases the serialization_strategy argument is not sufficient because
+            serialization requires specialized API calls, e.g. to call an S3 API directly instead
+            of using a generic file object. See ``dagster_pyspark.DataFrame`` for an example.
+
+    '''
+
+    def __init__(self, python_types, key=None, name=None, description=None, **kwargs):
+        # ugly workaround to handle unions in tuples
+        self.python_types = check.tuple_param(
+            python_types, 'python_types', of_type=tuple(check.type_types for item in python_types)
+        )
+        self.type_str = 'Union[{}]'.format(
+            ', '.join(python_type.__name__ for python_type in python_types)
+        )
+        name = check.opt_str_param(name, 'name', self.type_str)
+        key = check.opt_str_param(key, 'key', name)
+        description = check.opt_str_param(description, 'description', name)
+
+        super(PythonUnionDagsterType, self).__init__(
+            key=key,
+            name=name,
+            description=description,
+            type_check_fn=self.type_check_method,
+            **kwargs
+        )
+
+    def type_check_method(self, _context, value):
+        if not isinstance(value, self.python_types):
+            return TypeCheck(
+                success=False,
+                description=(
+                    'Value of type {value_type} failed type check for Dagster type {dagster_type}, '
+                    'expected value to be within Python type {expected_type}.'
+                ).format(
+                    value_type=type(value), dagster_type=self.name, expected_type=self.type_str,
+                ),
+            )
+
+        return TypeCheck(success=True)
+
+
+class NoneableInputSchema(DagsterTypeLoader):
     def __init__(self, inner_dagster_type):
         self._inner_dagster_type = check.inst_param(
             inner_dagster_type, 'inner_dagster_type', DagsterType
         )
-        check.param_invariant(inner_dagster_type.input_hydration_config, 'inner_dagster_type')
-        self._schema_type = ConfigNoneable(inner_dagster_type.input_hydration_config.schema_type)
+        check.param_invariant(inner_dagster_type.loader, 'inner_dagster_type')
+        self._schema_type = ConfigNoneable(inner_dagster_type.loader.schema_type)
 
     @property
     def schema_type(self):
@@ -479,13 +579,11 @@ class NoneableInputSchema(InputHydrationConfig):
     def construct_from_config_value(self, context, config_value):
         if config_value is None:
             return None
-        return self._inner_dagster_type.input_hydration_config.construct_from_config_value(
-            context, config_value
-        )
+        return self._inner_dagster_type.loader.construct_from_config_value(context, config_value)
 
 
 def _create_nullable_input_schema(inner_type):
-    if not inner_type.input_hydration_config:
+    if not inner_type.loader:
         return None
 
     return NoneableInputSchema(inner_type)
@@ -507,7 +605,7 @@ class OptionalType(DagsterType):
             name=None,
             kind=DagsterTypeKind.NULLABLE,
             type_check_fn=self.type_check_method,
-            input_hydration_config=_create_nullable_input_schema(inner_type),
+            loader=_create_nullable_input_schema(inner_type),
         )
 
     @property
@@ -528,27 +626,25 @@ class OptionalType(DagsterType):
         return [self.inner_type.key]
 
 
-class ListInputSchema(InputHydrationConfig):
+class ListInputSchema(DagsterTypeLoader):
     def __init__(self, inner_dagster_type):
         self._inner_dagster_type = check.inst_param(
             inner_dagster_type, 'inner_dagster_type', DagsterType
         )
-        check.param_invariant(inner_dagster_type.input_hydration_config, 'inner_dagster_type')
-        self._schema_type = Array(inner_dagster_type.input_hydration_config.schema_type)
+        check.param_invariant(inner_dagster_type.loader, 'inner_dagster_type')
+        self._schema_type = Array(inner_dagster_type.loader.schema_type)
 
     @property
     def schema_type(self):
         return self._schema_type
 
     def construct_from_config_value(self, context, config_value):
-        convert_item = partial(
-            self._inner_dagster_type.input_hydration_config.construct_from_config_value, context
-        )
+        convert_item = partial(self._inner_dagster_type.loader.construct_from_config_value, context)
         return list(map(convert_item, config_value))
 
 
 def _create_list_input_schema(inner_type):
-    if not inner_type.input_hydration_config:
+    if not inner_type.loader:
         return None
 
     return ListInputSchema(inner_type)
@@ -563,7 +659,7 @@ class ListType(DagsterType):
             name=None,
             kind=DagsterTypeKind.LIST,
             type_check_fn=self.type_check_method,
-            input_hydration_config=_create_list_input_schema(inner_type),
+            loader=_create_list_input_schema(inner_type),
         )
 
     @property
@@ -620,8 +716,8 @@ class Stringish(DagsterType):
             name=name,
             kind=DagsterTypeKind.SCALAR,
             type_check_fn=self.type_check_method,
-            input_hydration_config=BuiltinSchemas.STRING_INPUT,
-            output_materialization_config=BuiltinSchemas.STRING_OUTPUT,
+            loader=BuiltinSchemas.STRING_INPUT,
+            materializer=BuiltinSchemas.STRING_OUTPUT,
             **kwargs
         )
 
