@@ -26,7 +26,8 @@ from dagster.core.definitions.resource import ScopedResourcesBuilder
 from dagster.core.definitions.solid import ISolidDefinition
 from dagster.core.execution.api import create_execution_plan, scoped_pipeline_context
 from dagster.core.execution.context_creation_pipeline import (
-    construct_pipeline_execution_context,
+    SystemPipelineExecutionContext,
+    construct_execution_context_data,
     create_context_creation_data,
     create_executor,
     create_log_manager,
@@ -36,13 +37,12 @@ from dagster.core.scheduler import ScheduleStatus, Scheduler
 from dagster.core.scheduler.scheduler import DagsterScheduleDoesNotExist, DagsterSchedulerError
 from dagster.core.snap import snapshot_from_execution_plan
 from dagster.core.storage.file_manager import LocalFileManager
-from dagster.core.storage.intermediates_manager import InMemoryIntermediatesManager
+from dagster.core.storage.intermediate_storage import InMemoryIntermediateStorage
 from dagster.core.storage.pipeline_run import PipelineRun
 from dagster.core.types.dagster_type import resolve_dagster_type
 from dagster.core.utility_solids import define_stub_solid
 from dagster.core.utils import make_new_run_id
 from dagster.serdes import ConfigurableClass
-from dagster.utils.backcompat import canonicalize_run_config
 
 # pylint: disable=unused-import
 from ..temp_file import (
@@ -57,6 +57,8 @@ from ..typing_api import is_typing_type
 
 
 def create_test_pipeline_execution_context(logger_defs=None):
+    from dagster.core.storage.intermediate_storage import build_in_mem_intermediates_storage
+
     loggers = check.opt_dict_param(
         logger_defs, 'logger_defs', key_type=str, value_type=LoggerDefinition
     )
@@ -72,16 +74,22 @@ def create_test_pipeline_execution_context(logger_defs=None):
     log_manager = create_log_manager(creation_data)
     scoped_resources_builder = ScopedResourcesBuilder()
     executor = create_executor(creation_data)
-    return construct_pipeline_execution_context(
-        context_creation_data=creation_data,
-        scoped_resources_builder=scoped_resources_builder,
-        system_storage_data=SystemStorageData(
-            intermediates_manager=InMemoryIntermediatesManager(),
-            file_manager=LocalFileManager.for_instance(instance, pipeline_run.run_id),
+
+    return SystemPipelineExecutionContext(
+        construct_execution_context_data(
+            context_creation_data=creation_data,
+            scoped_resources_builder=scoped_resources_builder,
+            intermediate_storage=build_in_mem_intermediates_storage(pipeline_run.run_id),
+            system_storage_data=SystemStorageData(
+                intermediate_storage=InMemoryIntermediateStorage(),
+                file_manager=LocalFileManager.for_instance(instance, pipeline_run.run_id),
+            ),
+            log_manager=log_manager,
+            retries=executor.retries,
+            raise_on_error=True,
         ),
-        log_manager=log_manager,
         executor=executor,
-        raise_on_error=True,
+        log_manager=log_manager,
     )
 
 
@@ -137,7 +145,6 @@ def execute_solids_within_pipeline(
     preset=None,
     tags=None,
     instance=None,
-    environment_dict=None,
 ):
     '''Execute a set of solids within an existing pipeline.
 
@@ -168,9 +175,6 @@ def execute_solids_within_pipeline(
     check.set_param(solid_names, 'solid_names', of_type=str)
     inputs = check.opt_dict_param(inputs, 'inputs', key_type=str, value_type=dict)
 
-    # backcompact
-    run_config = canonicalize_run_config(run_config, environment_dict)
-
     sub_pipeline = pipeline_def.get_pipeline_subset_def(solid_names)
     stubbed_pipeline = build_pipeline_with_input_stubs(sub_pipeline, inputs)
     result = execute_pipeline(
@@ -194,7 +198,6 @@ def execute_solid_within_pipeline(
     preset=None,
     tags=None,
     instance=None,
-    environment_dict=None,
 ):
     '''Execute a single solid within an existing pipeline.
 
@@ -221,8 +224,6 @@ def execute_solid_within_pipeline(
         Union[CompositeSolidExecutionResult, SolidExecutionResult]: The result of executing the
         solid.
     '''
-    # backcompact
-    run_config = canonicalize_run_config(run_config, environment_dict)
 
     return execute_solids_within_pipeline(
         pipeline_def,
@@ -268,13 +269,7 @@ def yield_empty_pipeline_context(run_id=None, instance=None):
 
 
 def execute_solid(
-    solid_def,
-    mode_def=None,
-    input_values=None,
-    tags=None,
-    run_config=None,
-    raise_on_error=True,
-    environment_dict=None,
+    solid_def, mode_def=None, input_values=None, tags=None, run_config=None, raise_on_error=True,
 ):
     '''Execute a single solid in an ephemeral pipeline.
 
@@ -302,9 +297,6 @@ def execute_solid(
     check.inst_param(solid_def, 'solid_def', ISolidDefinition)
     check.opt_inst_param(mode_def, 'mode_def', ModeDefinition)
     input_values = check.opt_dict_param(input_values, 'input_values', key_type=str)
-    # backcompact
-    run_config = canonicalize_run_config(run_config, environment_dict)
-
     solid_defs = [solid_def]
 
     def create_value_solid(input_name, input_value):
@@ -397,7 +389,7 @@ class FilesystemTestScheduler(Scheduler, ConfigurableClass):
     '''This class is used in dagster core and dagster_graphql to test the scheduler's interactions
     with schedule storage, which are implemented in the methods defined on the base Scheduler class.
     Therefore, the following methods used to actually schedule jobs (e.g. create and remove cron jobs
-    on a cron tab) are left unimimplemented.
+    on a cron tab) are left unimplemented.
     '''
 
     def __init__(self, artifacts_dir, inst_data=None):
